@@ -8,6 +8,7 @@ use pf::config;
 use pf::web qw(i18n i18n_format);
 use pf::node;
 use pf::util;
+use pf::config::util;
 use pf::locationlog;
 use pf::authentication;
 use pf::Authentication::constants;
@@ -504,11 +505,14 @@ sub authenticationLogin : Private {
     }
     $c->stash( profile => $profile );
 
-    my @sources = $self->getSources($c);
 
     my $username = _clean_username($request->param("username"));
+    my $realm;
+    ($username, $realm) = strip_username($username);
     my $password = $request->param("password");
 
+    my @sources = $self->getSources($c, $username, $realm);
+
     if(isenabled($profile->reuseDot1xCredentials)) {
         my $mac       = $portalSession->clientMac;
         my $node_info = node_view($mac);
@@ -526,6 +530,7 @@ sub authenticationLogin : Private {
         ( $return, $message, $source_id ) =
           pf::authentication::authenticate( { 'username' => $username, 'password' => $password, 'rule_class' => $Rules::AUTH }, @sources );
         if ( defined($return) && $return == 1 ) {
+            pf::auth_log::record_auth($source_id, $portalSession->clientMac, $username, $pf::auth_log::COMPLETED);
             # save login into session
             $c->session(
                 "username"  => $username // $default_pid,
@@ -535,6 +540,7 @@ sub authenticationLogin : Private {
             # Logging USER/IP/MAC of the just-authenticated user
             $logger->info("Successfully authenticated ".$username."/".$portalSession->clientIp."/".$portalSession->clientMac);
         } else {
+            pf::auth_log::record_auth(join(',',map { $_->id } @sources), $portalSession->clientMac, $username, $pf::auth_log::FAILED);
             $c->error($message);
         }
     }
@@ -547,7 +553,7 @@ Return the source to use to login
 =cut
 
 sub getSources : Private {
-    my ($self,$c) = @_;
+    my ($self,$c,$stripped_username,$realm) = @_;
     my @sources;
     my $use_local_source = $c->stash->{use_local_source};
     my $profile = $c->stash->{profile};
@@ -563,6 +569,15 @@ sub getSources : Private {
                 ( $profile->getInternalSources, $profile->getExclusiveSources );
         }
     }
+
+    my $realm_source = get_realm_source($stripped_username, $realm);
+    if( $realm_source && any { $_ eq $realm_source} @sources ){
+        $c->log->info("Realm source is part of the portal profile sources. Using it as the only auth source.");
+        return ($realm_source);
+    }
+    elsif ( $realm_source ) {
+        $c->log->info("Realm source ".$realm_source->id." is configured in the realm $realm but is not in the portal profile. Ignoring it and using the portal profile sources.");
+    }
     return @sources;
 }
 
@@ -705,7 +720,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2015 Inverse inc.
+Copyright (C) 2005-2016 Inverse inc.
 
 =head1 LICENSE
 
