@@ -180,7 +180,7 @@ sub view {
         if ($node->{iplog}->{'ip'}) {
             $node->{iplog}->{active} = 1;
         } else {
-            my $last_iplog = pop @iplog_history;
+            my $last_iplog = shift @iplog_history;
             $node->{iplog}->{ip} = $last_iplog->{ip};
             $node->{iplog}->{end_time} = $last_iplog->{end_time};
         }
@@ -281,7 +281,7 @@ sub update {
         if ($previous_node_ref->{status} ne $node_ref->{status} || $previous_category_id ne $category_id) {
             # Node has been registered or deregistered
             # or the role has changed and is not currently using 802.1X
-            reevaluate_access($mac, "node_modify");
+            reevaluate_access($mac, "admin_modify");
         }
     }
     else {
@@ -371,6 +371,12 @@ sub importCSV {
                'voip'        => $index{'voip'}      ? $row->[$index{'voip'}]      : $default_voip,
                'notes'       => $index{'notes'}     ? $row->[$index{'notes'}]     : undef,
               );
+            if (exists $index{'bypass_vlan'}) {
+                    $data{'bypass_vlan'} = $row->[$index{'bypass_vlan'}];
+            }
+            if (exists $index{'bypass_role'}) {
+                $data{'bypass_role_id'} = nodecategory_lookup($row->[$index{'bypass_role'}]);
+            }
             if (!defined($node) || (ref($node) eq 'HASH' && $node->{'status'} ne $pf::node::STATUS_REGISTERED)) {
                 $logger->debug("Register MAC $mac ($pid)");
                 $result = node_register($mac, $pid, %data);
@@ -485,7 +491,7 @@ sub violations {
 sub addViolation {
     my ($self, $mac, $vid) = @_;
 
-    if (violation_add($mac, $vid)) {
+    if (violation_add($mac, $vid, ('force' => $TRUE))) {
         return ($STATUS::OK, 'The violation was successfully added.');
     }
     else {
@@ -818,7 +824,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2015 Inverse inc.
+Copyright (C) 2005-2016 Inverse inc.
 
 =head1 LICENSE
 
