@@ -89,7 +89,7 @@ sub read {
         return ($STATUS::OK, \@sorted_users);
     }
     else {
-        return ($STATUS::NOT_FOUND);
+        return ($STATUS::NOT_FOUND, "Item(s) not found");
     }
 }
 
@@ -663,7 +663,7 @@ sub bulkCloseViolations {
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2015 Inverse inc.
+Copyright (C) 2005-2016 Inverse inc.
 
 =head1 LICENSE
 
