@@ -41,6 +41,8 @@ var NodeView = function(options) {
     var read = $.proxy(this.readNode, this);
     options.parent.on('click', '#nodes [href*="node"][href$="/read"]', read);
 
+    this.proxyClick($('body'), '.node [href*="node"][href$="/read"]', this.readNode);
+
     this.proxyFor($('body'), 'show', '#modalNode', this.showNode);
 
     this.proxyFor($('body'), 'submit', 'form[name="nodes"]', this.createNode);
@@ -380,7 +382,7 @@ NodeView.prototype.reorderSearch = function(e) {
     var that = this;
     var link = $(e.currentTarget);
     var pagination = $('.pagination').first();
-    var formId = pagination.attr('data-from-from') || '#search';
+    var formId = pagination.attr('data-from-form') || '#search';
     var form = $(formId);
     if(form.length == 0) {
         form = $('#search');
@@ -416,7 +418,7 @@ NodeView.prototype.searchPagination = function(e) {
     e.preventDefault();
     var link = $(e.currentTarget);
     var pagination = link.closest('.pagination');
-    var formId = pagination.attr('data-from-from') || '#search';
+    var formId = pagination.attr('data-from-form') || '#search';
     var form = $(formId);
     if(form.length == 0) {
         form = $('#search');
@@ -449,7 +451,7 @@ NodeView.prototype.searchPagination = function(e) {
 NodeView.prototype.refreshPage = function() {
     var that = this;
     var pagination = $('.pagination').first();
-    var formId = pagination.attr('data-from-from') || '#search';
+    var formId = pagination.attr('data-from-form') || '#search';
     var form = $(formId);
     var link = pagination.find('li.disabled a').first();
     if(form.length == 0) {
@@ -528,19 +530,24 @@ NodeView.prototype.toggleAllItems = function(e) {
 NodeView.prototype.submitItems = function(e) {
     var that = this;
     var target = $(e.currentTarget);
-    var status_container = $("#section").find('h2').first();
+    var section = $('#section');
+    var loader = section.prev('.loader');
+    var status_container = section.find('h2').first();
     var items = $("#items").serialize();
     if (items.length) {
-        this.nodes.post({
-            url: target.attr("data-target"),
-            data: items,
-            success: function(data) {
-                $("#section").one('section.loaded', function() {
-                    showSuccess($("#section").find('h2').first(), data.status_msg);
-                });
-                that.refreshPage();
-            },
-            errorSibling: status_container
+        loader.show();
+        section.fadeTo('fast', 0.5, function() {
+            that.nodes.post({
+                url: target.attr("data-target"),
+                data: items,
+                success: function(data) {
+                    $("#section").one('section.loaded', function() {
+                        showSuccess($("#section").find('h2').first(), data.status_msg);
+                    });
+                    that.refreshPage();
+                },
+                errorSibling: status_container
+            });
         });
     }
 };
