@@ -18,7 +18,7 @@ use pf::file_paths;
 use pf::util;
 extends 'pf::ConfigStore';
 
-sub configFile { $pf::file_paths::billing_tiers_config_file };
+sub configFile { $billing_tiers_config_file };
 
 sub pfconfigNamespace {'config::BillingTiers'}
 
@@ -28,7 +28,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2015 Inverse inc.
+Copyright (C) 2005-2016 Inverse inc.
 
 =head1 LICENSE
 
