@@ -19,7 +19,7 @@ use pf::file_paths;
 extends 'pf::ConfigStore';
 
 
-sub configFile { $pf::file_paths::floating_devices_config_file }
+sub configFile { $floating_devices_config_file }
 
 sub pfconfigNamespace {'config::FloatingDevices'}
 
@@ -27,7 +27,7 @@ __PACKAGE__->meta->make_immutable;
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2015 Inverse inc.
+Copyright (C) 2005-2016 Inverse inc.
 
 =head1 LICENSE
 
