@@ -17,7 +17,7 @@ use Moo;
 use pf::file_paths;
 extends 'pf::ConfigStore';
 
-sub configFile { $pf::file_paths::vlan_filters_config_file };
+sub configFile { $vlan_filters_config_file };
 
 sub pfconfigNamespace {'config::VlanFilters'}
 
@@ -29,7 +29,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2015 Inverse inc.
+Copyright (C) 2005-2016 Inverse inc.
 
 =head1 LICENSE
 
