@@ -43,8 +43,10 @@ use fingerbank::DB;
 use File::Slurp;
 use pf::file_paths;
 use pf::CHI;
+use pf::access_filter::dhcp;
 
 use List::MoreUtils qw(uniq);
+use File::Copy::Recursive qw(dircopy);
 use NetAddr::IP;
 use pf::factory::firewallsso;
 
@@ -141,6 +143,27 @@ sub soh_authorize : Public {
     return $return;
 }
 
+=head2 radius_switch_access
+
+Return RADIUS attributes to allow switch's CLI access
+
+=cut
+
+sub radius_switch_access : Public {
+    my ($class, %radius_request) = @_;
+    my $logger = pf::log::get_logger();
+
+    my $radius = new pf::radius::custom();
+    my $return;
+    eval {
+        $return = $radius->switch_access(\%radius_request);
+    };
+    if ($@) {
+        $logger->error("radius switch access failed with error: $@");
+    }
+    return $return;
+}
+
 sub update_iplog : Public {
     my ($class, %postdata) = @_;
     my @require = qw(mac ip);
@@ -185,17 +208,17 @@ sub unreg_node_for_pid : Public {
 }
 
 sub synchronize_locationlog : Public {
-    my ( $class, $switch, $switch_ip, $switch_mac, $ifIndex, $vlan, $mac, $voip_status, $connection_type, $connection_sub_type, $user_name, $ssid ,$stripped_user_name, $realm) = @_;
+    my ( $class, $switch, $switch_ip, $switch_mac, $ifIndex, $vlan, $mac, $voip_status, $connection_type, $connection_sub_type, $user_name, $ssid ,$stripped_user_name, $realm, $role) = @_;
     my $logger = pf::log::get_logger();
 
-    return (pf::locationlog::locationlog_synchronize($switch, $switch_ip, $switch_mac, $ifIndex, $vlan, $mac, $voip_status, $connection_type, $connection_sub_type, $user_name, $ssid, $stripped_user_name, $realm));
+    return (pf::locationlog::locationlog_synchronize($switch, $switch_ip, $switch_mac, $ifIndex, $vlan, $mac, $voip_status, $connection_type, $connection_sub_type, $user_name, $ssid, $stripped_user_name, $realm, $role));
 }
 
 sub insert_close_locationlog : Public {
-    my ($class, $switch, $switch_ip, $switch_mac, $ifIndex, $vlan, $mac, $connection_type, $connection_sub_type, $user_name, $ssid, $stripped_user_name, $realm);
+    my ($class, $switch, $switch_ip, $switch_mac, $ifIndex, $vlan, $mac, $connection_type, $connection_sub_type, $user_name, $ssid, $stripped_user_name, $realm, $role);
     my $logger = pf::log::get_logger();
 
-    return(pf::locationlog::locationlog_insert_closed($switch, $switch_ip, $switch_mac, $ifIndex, $vlan, $mac, $connection_type, $connection_sub_type, $user_name, $ssid, $stripped_user_name, $realm));
+    return(pf::locationlog::locationlog_insert_closed($switch, $switch_ip, $switch_mac, $ifIndex, $vlan, $mac, $connection_type, $connection_sub_type, $user_name, $ssid, $stripped_user_name, $realm, $role));
 }
 
 sub open_iplog : Public {
@@ -239,6 +262,7 @@ sub firewallsso : Public {
                     sub {
                         $logger->debug("Doing cached firewall SSO for '$cache_key' with expiration of $cache_timeout");
                         $firewall->action($firewall_id,'Start',$postdata{'mac'},$postdata{'ip'},$postdata{'timeout'});
+                        return 1;
                     }
                 );
             }
@@ -371,9 +395,17 @@ Set the vlan for the node on the switch
 sub _node_determine_and_set_into_VLAN {
     my ( $mac, $switch, $ifIndex, $connection_type ) = @_;
 
-    my $vlan_obj = new pf::vlan::custom();
+    my $role_obj = new pf::role::custom();
+    my $args = {
+        mac => $mac,
+        node_info => pf::node::node_attributes($mac),
+        switch => $switch,
+        ifIndex => $ifIndex,
+        connection_type => $connection_type,
+    };
 
-    my ($vlan,$wasInline) = $vlan_obj->fetchVlanForNode($mac, $switch, $ifIndex, $connection_type);
+    my $role = $role_obj->fetchRoleForNode($args);
+    my $vlan = $role->{vlan} || $switch->getVlanByName($role->{role});
 
     my %locker_ref;
     $locker_ref{$switch->{_ip}} = &share({});
@@ -874,7 +906,8 @@ sub dynamic_register_node : Public {
     my $logger = pf::log::get_logger();
     my $profile = pf::Portal::ProfileFactory->instantiate($postdata{'mac'});
     my $node_info = pf::node::node_view($postdata{'mac'});
-    my @sources = ($profile->getInternalSources, $profile->getExclusiveSources );
+    # We try this although the realm is not mandatory in case it proves to be useful in the future
+    my @sources = get_user_sources($profile, $postdata{'username'}, $postdata{'realm'}); 
     my $stripped_user = '';
 
     my $params = {
@@ -912,8 +945,13 @@ sub dynamic_register_node : Public {
 
 sub fingerbank_process : Public {
     my ( $class, $args ) = @_;
-
-    return (pf::fingerbank::process($args));
+    my $filter = pf::access_filter::dhcp->new;
+    my $rule = $filter->filter('DhcpFingerbank', $args);
+    if (!$rule) {
+        delete $args->{'computer_name'};
+        return (pf::fingerbank::process($args));
+    }
+    return undef;
 }
 
 =head2 fingerbank_update_upstream_db
@@ -1003,7 +1041,7 @@ The UDP payload must be base 64 encoded.
 
 sub process_dhcp : Public {
     my ($class, %postdata) = @_;
-    my @require = qw(src_mac src_ip dest_mac dest_ip running_w_dhcpd is_inline_vlan interface interface_ip interface_vlan net_type udp_payload_b64);
+    my @require = qw(src_mac src_ip dest_mac dest_ip is_inline_vlan interface interface_ip interface_vlan net_type udp_payload_b64);
     my @found = grep {exists $postdata{$_}} @require;
     return unless validate_argv(\@require,\@found);
     
@@ -1059,8 +1097,8 @@ sub process_dhcpv6 : Public {
             $logger->debug("Found DHCPv6 link address (MAC) '$mac_address'");
         }
     }
-
-    $logger->trace("[$mac_address] Found DHCPv6 packet with fingerprint '$dhcp6_fingerprint' and enterprise ID '$dhcp6_enterprise'.");
+    Log::Log4perl::MDC->put('mac', $mac_address);
+    $logger->trace("Found DHCPv6 packet with fingerprint '$dhcp6_fingerprint' and enterprise ID '$dhcp6_enterprise'.");
 
     my %fingerbank_query_args = (
         mac                 => $mac_address,
@@ -1073,13 +1111,24 @@ sub process_dhcpv6 : Public {
     pf::node::node_modify($mac_address, dhcp6_fingerprint => $dhcp6_fingerprint, dhcp6_enterprise => $dhcp6_enterprise);
 }
 
+=head2 copy_directory
+
+Copy a directory on this server
+
+=cut
+
+sub copy_directory : Public {
+    my ($class, $source_dir, $dest_dir) = @_;
+    return dircopy($source_dir, $dest_dir);
+}
+
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2015 Inverse inc.
+Copyright (C) 2005-2016 Inverse inc.
 
 =head1 LICENSE
 
