@@ -123,6 +123,8 @@ our (
     %ConfigDetect,
 #billing_tiers.conf
     %ConfigBillingTiers,
+#adminroles.conf
+    %ConfigAdminRoles,
 );
 
 BEGIN {
@@ -151,8 +153,8 @@ BEGIN {
         $VOIP $NO_VOIP $NO_PORT $NO_VLAN
         %connection_type %connection_type_to_str %connection_type_explained
         %connection_group %connection_group_to_str
-        $RADIUS_API_LEVEL $VLAN_API_LEVEL $INLINE_API_LEVEL $AUTHENTICATION_API_LEVEL $SOH_API_LEVEL $BILLING_API_LEVEL
-        $ROLE_API_LEVEL
+        $RADIUS_API_LEVEL $ROLE_API_LEVEL $INLINE_API_LEVEL $AUTHENTICATION_API_LEVEL $SOH_API_LEVEL $BILLING_API_LEVEL
+        $ROLES_API_LEVEL
         $SELFREG_MODE_EMAIL $SELFREG_MODE_SMS $SELFREG_MODE_SPONSOR $SELFREG_MODE_GOOGLE $SELFREG_MODE_FACEBOOK $SELFREG_MODE_GITHUB $SELFREG_MODE_LINKEDIN $SELFREG_MODE_WIN_LIVE $SELFREG_MODE_TWITTER $SELFREG_MODE_NULL $SELFREG_MODE_KICKBOX $SELFREG_MODE_CHAINED
         %CAPTIVE_PORTAL
         $HTTP $HTTPS
@@ -174,6 +176,7 @@ BEGIN {
         %ConfigPKI_Provider
         %ConfigDetect
         %ConfigBillingTiers
+        %ConfigAdminRoles
     );
 }
 
@@ -242,6 +245,8 @@ tie %ConfigDetect, 'pfconfig::cached_hash', 'config::Pfdetect';
 
 tie %ConfigBillingTiers, 'pfconfig::cached_hash', 'config::BillingTiers';
 
+tie %ConfigAdminRoles, 'pfconfig::cached_hash', 'config::AdminRoles';
+
 sub import {
     pf::config->export_to_level(1,@_);
     pf::file_paths->export_to_level(1);
@@ -341,12 +346,12 @@ Readonly our $HTTPS => 'https';
 
 # API version constants
 Readonly::Scalar our $RADIUS_API_LEVEL => 1.02;
-Readonly::Scalar our $VLAN_API_LEVEL => 1.04;
+Readonly::Scalar our $ROLE_API_LEVEL => 1.04;
 Readonly::Scalar our $INLINE_API_LEVEL => 1.01;
 Readonly::Scalar our $AUTHENTICATION_API_LEVEL => 1.11;
 Readonly::Scalar our $SOH_API_LEVEL => 1.00;
 Readonly::Scalar our $BILLING_API_LEVEL => 1.00;
-Readonly::Scalar our $ROLE_API_LEVEL => 0.90;
+Readonly::Scalar our $ROLES_API_LEVEL => 0.90;
 
 # to shut up strict warnings
 $ENV{PATH} = '/sbin:/bin:/usr/bin:/usr/sbin';
@@ -882,6 +887,7 @@ sub configreload {
     require pf::ConfigStore::Wrix;
     require pf::ConfigStore::VlanFilters;
     require pf::ConfigStore::RadiusFilters;
+    require pf::ConfigStore::DhcpFilters;
     require pf::web::filter;
     pf::config::cached::updateCacheControl();
     pf::config::cached::ReloadConfigs($force);
@@ -912,7 +918,7 @@ Minor parts of this file may have been contributed. See CREDITS.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2015 Inverse inc.
+Copyright (C) 2005-2016 Inverse inc.
 
 Copyright (C) 2005 Kevin Amorin
 
