@@ -16,17 +16,41 @@ use strict;
 use warnings;
 use base qw(Exporter);
 
-our @EXPORT_OK = qw($PFQUEUE_COUNTER);
+our @EXPORT_OK = qw(
+    $PFQUEUE_COUNTER
+    $PFQUEUE_QUEUE_PREFIX
+    $PFQUEUE_EXPIRED_COUNTER
+    $PFQUEUE_WORKERS_DEFAULT
+    $PFQUEUE_DELAYED_QUEUE_BATCH_DEFAULT
+    $PFQUEUE_DELAYED_QUEUE_WORKERS_DEFAULT
+    $PFQUEUE_DELAYED_QUEUE_SLEEP_DEFAULT
+);
+
+our %EXPORT_TAGS = (
+    all => \@EXPORT_OK,
+);
 
 our $PFQUEUE_COUNTER = "TaskCounters";
 
+our $PFQUEUE_EXPIRED_COUNTER = "ExpiredCounters";
+
+our $PFQUEUE_QUEUE_PREFIX = "Queue:";
+
+our $PFQUEUE_WORKERS_DEFAULT = 10;
+
+our $PFQUEUE_DELAYED_QUEUE_BATCH_DEFAULT = 100;
+
+our $PFQUEUE_DELAYED_QUEUE_WORKERS_DEFAULT = 1;
+
+our $PFQUEUE_DELAYED_QUEUE_SLEEP_DEFAULT = 100;
+
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2015 Inverse inc.
+Copyright (C) 2005-2016 Inverse inc.
 
 =head1 LICENSE
 
