@@ -37,6 +37,7 @@ use pf::api::jsonrpcclient;
 use NetAddr::IP;
 use pf::SwitchFactory;
 use pf::log;
+use pf::StatsD::Timer;
 
 our $logger = get_logger;
 my $ROGUE_DHCP_TRIGGER = '1100010';
@@ -79,9 +80,31 @@ sub new {
         $self->{accessControl} = new pf::inline::custom();
     }
     $self->{api_client} = pf::client::getClient();
+    $self->_build_DHCP_networks();
     return $self;
 }
 
+=head2 _build_DHCP_networks
+
+Builds the list of networks on which PacketFence is the DHCP server
+
+=cut
+
+sub _build_DHCP_networks {
+    my ($self) = @_;
+
+    my @dhcp_networks;
+    foreach my $network (keys %ConfigNetworks) {
+        my %net = %{$ConfigNetworks{$network}};
+        my $network_obj = NetAddr::IP->new($network,$ConfigNetworks{$network}{netmask});
+        if(isenabled($net{dhcpd})){
+            push @dhcp_networks, $network_obj;
+        }
+    }
+
+    $self->{dhcp_networks} = \@dhcp_networks;
+}
+
 =head2 _get_redis_client
 
 Get the redis client
@@ -107,6 +130,7 @@ Process a packet
 =cut
 
 sub process_packet {
+    my $timer = pf::StatsD::Timer->new();
     my ( $self ) = @_;
 
     my ($dhcp);
@@ -207,6 +231,7 @@ sub process_packet {
             dhcp_fingerprint    => $tmp{'dhcp_fingerprint'},
             dhcp_vendor         => $tmp{'dhcp_vendor'},
             mac                 => $dhcp->{'chaddr'},
+            computer_name       => $tmp{'computername'},
         );
 
         # When listening on the mgmt interface, we can't rely on yiaddr as we only see requests
@@ -241,6 +266,7 @@ sub parse_dhcp_discover {
 =cut
 
 sub parse_dhcp_offer {
+    my $timer = pf::StatsD::Timer->new();
     my ($self, $dhcp) = @_;
 
     if ($dhcp->{'yiaddr'} =~ /^0\.0\.0\.0$/) {
@@ -258,6 +284,7 @@ sub parse_dhcp_offer {
 =cut
 
 sub parse_dhcp_request {
+    my $timer = pf::StatsD::Timer->new();
     my ($self, $dhcp) = @_;
     $logger->debug("DHCPREQUEST from $dhcp->{'chaddr'}");
 
@@ -274,7 +301,7 @@ sub parse_dhcp_request {
 
     # We check if we are running without dhcpd
     # This means we don't see ACK so we need to act on requests
-    if((!$self->{running_w_dhcpd} && !isenabled($Config{network}{force_listener_update_on_ack})) && (defined($client_ip) && defined($client_mac))){
+    if( (defined($client_ip) && defined($client_mac)) && (!$self->pf_is_dhcp($client_ip) && !isenabled($Config{network}{force_listener_update_on_ack})) ){
         $self->handle_new_ip($client_mac, $client_ip, $lease_length);
     }
 
@@ -284,10 +311,13 @@ sub parse_dhcp_request {
         $self->rogue_dhcp_handling($dhcp->{'options'}{54}, undef, $client_ip, $dhcp->{'chaddr'}, $dhcp->{'giaddr'});
     }
 
-    if ($self->{is_inline_vlan} || grep ( { $_->{'gateway'} eq $dhcp->{'src_ip'} } @inline_nets)) {
+    if ($self->{is_inline_vlan} || grep ( { defined $_->{'gateway'} && $_->{'gateway'} eq $dhcp->{'src_ip'} } @inline_nets)) {
         $self->{api_client}->notify('synchronize_locationlog',$self->{interface_ip},$self->{interface_ip},undef, $NO_PORT, $self->{interface_vlan}, $dhcp->{'chaddr'}, $NO_VOIP, $INLINE);
         $self->{accessControl}->performInlineEnforcement($dhcp->{'chaddr'});
     }
+    else {
+        $logger->debug("Not acting on DHCPREQUEST");
+    }
 }
 
 
@@ -296,6 +326,7 @@ sub parse_dhcp_request {
 =cut
 
 sub parse_dhcp_ack {
+    my $timer = pf::StatsD::Timer->new();
     my ($self, $dhcp) = @_;
 
     my $s_ip = $dhcp->{'src_ip'};
@@ -312,7 +343,7 @@ sub parse_dhcp_ack {
         );
         $client_ip = $dhcp->{'yiaddr'};
         $client_mac = $dhcp->{'chaddr'};
-    } 
+    }
     elsif ($dhcp->{'ciaddr'} !~ /^0\.0\.0\.0$/) {
 
         $logger->info(
@@ -321,7 +352,7 @@ sub parse_dhcp_ack {
         );
         $client_ip = $dhcp->{'ciaddr'};
         $client_mac = $dhcp->{'chaddr'};
-    } 
+    }
     else {
         $logger->warn(
             "invalid DHCPACK from $s_ip ($s_mac) to host $dhcp->{'chaddr'} [$dhcp->{yiaddr} - $dhcp->{ciaddr}]"
@@ -331,7 +362,7 @@ sub parse_dhcp_ack {
     # We check if we are running with the DHCPd process.
     # If yes, we are interested with the ACK
     # Packet also has to be valid
-    if(($self->{running_w_dhcpd} || isenabled($Config{network}{force_listener_update_on_ack})) && (defined($client_ip) && defined($client_mac))){
+    if( (defined($client_ip) && defined($client_mac)) && ($self->pf_is_dhcp($client_ip) || isenabled($Config{network}{force_listener_update_on_ack})) ){
         $self->handle_new_ip($client_mac, $client_ip, $lease_length);
     }
     else {
@@ -340,6 +371,28 @@ sub parse_dhcp_ack {
 
 }
 
+=head2 pf_is_dhcp
+
+Verifies if PacketFence is the DHCP server for the network the IP is in
+
+=cut
+
+sub pf_is_dhcp {
+    my ($self, $client_ip) = @_;
+
+    foreach my $network_obj (@{$self->{dhcp_networks}}) {
+        # We need to rebuild it everytime with the mask from the network as
+        # a DHCPREQUEST does not contain the subnet mask
+        my $net_addr = NetAddr::IP->new($client_ip,$network_obj->mask);
+        if($network_obj->contains($net_addr)){
+            $logger->info("The listener process is on the same server as the DHCP server.");
+            return $TRUE;
+        }
+    }
+    $logger->info("The listener process is NOT on the same server as the DHCP server.");
+    return $FALSE;
+}
+
 =head2 handle_new_ip
 
 Handle the tasks related to a device getting an IP address
@@ -347,6 +400,7 @@ Handle the tasks related to a device getting an IP address
 =cut
 
 sub handle_new_ip {
+    my $timer = pf::StatsD::Timer->new();
     my ($self, $client_mac, $client_ip, $lease_length) = @_;
     $logger->info("Updating iplog and SSO for $client_mac -> $client_ip");
     $self->update_iplog( $client_mac, $client_ip, $lease_length );
@@ -366,6 +420,7 @@ sub handle_new_ip {
 =cut
 
 sub parse_dhcp_release {
+    my $timer = pf::StatsD::Timer->new();
     my ($self, $dhcp) = @_;
     $logger->debug("DHCPRELEASE from $dhcp->{'chaddr'} ($dhcp->{ciaddr})");
     $self->{api_client}->notify('close_iplog',$dhcp->{'ciaddr'});
@@ -389,6 +444,7 @@ Optional but very useful DHCP Server MAC
 =cut
 
 sub rogue_dhcp_handling {
+    my $timer = pf::StatsD::Timer->new();
     my ($self, $dhcp_srv_ip, $dhcp_srv_mac, $offered_ip, $client_mac, $relay_ip) = @_;
 
     return if (isdisabled($Config{'network'}{'rogue_dhcp_detection'}));
@@ -478,7 +534,7 @@ Otherwise, an empty array is returned
 sub add_rogue_dhcp {
     my ($self, $rogue_dhcp, $offer, $threshold) = @_;
     my @offers = $self->_get_redis_client->evalsha($LUA_ROGUE_DHCP_SHA1, 0, $rogue_dhcp, $offer, $threshold);
-    return \@offers; 
+    return \@offers;
 }
 
 =head2 parse_dhcp_option82
@@ -488,6 +544,7 @@ Option 82 is Relay Agent Information. Defined in RFC 3046.
 =cut
 
 sub parse_dhcp_option82 {
+    my $timer = pf::StatsD::Timer->new();
     my ($self, $dhcp) = @_;
 
     # slicing the hash to retrive the stuff we are interested in
@@ -508,6 +565,7 @@ Also handles the SSO stop if the IP changes
 =cut
 
 sub update_iplog {
+    my $timer = pf::StatsD::Timer->new();
     my ( $self, $srcmac, $srcip, $lease_length ) = @_;
     $logger->debug("$srcip && $srcmac");
 
@@ -589,7 +647,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2015 Inverse inc.
+Copyright (C) 2005-2016 Inverse inc.
 
 =head1 LICENSE
 
@@ -609,4 +667,5 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 USA.
 
 =cut
+
 1;
