@@ -44,7 +44,8 @@ Generate the task id
 =cut
 
 sub generateId {
-   "Task:" . $GENERATOR->create_str
+    my ($self, $metadata) = @_;
+   "Task:" . $GENERATOR->create_str . ":$metadata";
 }
 
 
@@ -54,7 +55,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2015 Inverse inc.
+Copyright (C) 2005-2016 Inverse inc.
 
 =head1 LICENSE
 
