@@ -71,6 +71,7 @@ BEGIN {
         fix_file_permissions
         strip_username
         generate_session_id
+        calc_page_count
     );
 }
 
@@ -1138,6 +1139,17 @@ sub generate_session_id {
     return substr(Digest::MD5::md5_hex(Digest::MD5::md5_hex(time(). {}. rand(). $$)), 0, $length);
 }
 
+=item $pageCount = calc_page_count($count, $perPage)
+
+Calculates the number of pages
+
+=cut
+
+sub calc_page_count {
+    my ($count, $perPage) = @_;
+    return int( ($count + $perPage  - 1) / $perPage );
+}
+
 =back
 
 =head1 AUTHOR
@@ -1148,7 +1160,7 @@ Minor parts of this file may have been contributed. See CREDITS.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2015 Inverse inc.
+Copyright (C) 2005-2016 Inverse inc.
 
 Copyright (C) 2005 Kevin Amorin
 
