@@ -19,6 +19,8 @@ use pf::util;
 
 sub add_mac_to_log_context {
     my ($args) = @_;
+    Log::Log4perl::MDC->put('mac', 'unknown');
+    return unless defined $args;
     my $params;
     if (@$args == 1) {
         if (ref($args->[0]) eq 'HASH') {
@@ -44,7 +46,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2015 Inverse inc.
+Copyright (C) 2005-2016 Inverse inc.
 
 =head1 LICENSE
 
