@@ -22,6 +22,7 @@ use warnings;
 use pf::log;
 use Readonly;
 use POSIX;
+use JSON;
 use Time::HiRes qw(time);
 use pfconfig::cached_scalar;
 use pf::error qw(is_success is_error);
@@ -31,8 +32,7 @@ use fingerbank::Model::DHCP_Vendor;
 use fingerbank::Model::User_Agent;
 use pf::violation_config;
 use pf::node;
-use pf::StatsD;
-use pf::util::statsd qw(called);
+use pf::StatsD::Timer;
 
 
 # Violation status constants
@@ -48,8 +48,6 @@ use constant VIOLATION => 'violation';
 use pf::factory::condition::violation;
 pf::factory::condition::violation->modules;
 tie our $VIOLATION_FILTER_ENGINE , 'pfconfig::cached_scalar' => 'FilterEngine::Violation';
-tie our @BANDWIDTH_EXPIRED_VIOLATIONS, 'pfconfig::cached_array' => 'resource::bandwidth_expired_violations';
-tie our @ACCOUNTING_TRIGGERS, 'pfconfig::cached_array' => 'resource::accounting_triggers';
 
 BEGIN {
     use Exporter ();
@@ -89,9 +87,6 @@ BEGIN {
         violation_clear_errors
         violation_last_errors
         violation_run_delayed
-
-        @BANDWIDTH_EXPIRED_VIOLATIONS
-        @ACCOUNTING_TRIGGERS
     );
 }
 use pf::action;
@@ -424,9 +419,9 @@ sub violation_view_all_active {
 
 #
 sub violation_add {
+    my $timer = pf::StatsD::Timer->new;
     my ( $mac, $vid, %data ) = @_;
     my $logger = get_logger();
-    my $start = Time::HiRes::gettimeofday();
     return (0) if ( !$vid );
     violation_clear_warnings();
     violation_clear_errors();
@@ -443,7 +438,6 @@ sub violation_add {
         my $msg = "violation $vid already exists for $mac, not adding again";
         $logger->info($msg);
         violation_add_warnings($msg);
-        $pf::StatsD::statsd->end(called() . ".timing" , $start, 0.25 );
         return ($violation);
     }
 
@@ -456,7 +450,6 @@ sub violation_add {
             $logger->warn(
                 "hostscan detected from $mac, but violation $latest_vid exists - ignoring"
             );
-            $pf::StatsD::statsd->end(called() . ".timing" , $start, 0.25 );
             return (1);
         }
 
@@ -476,12 +469,14 @@ sub violation_add {
 
         # check if we are under the grace period of a previous violation
         my ($remaining_time) = violation_grace( $mac, $vid );
-        if ( $remaining_time > 0 ) {
+        if ( $remaining_time > 0 && $data{'force'} ne $TRUE ) {
             my $msg = "$remaining_time grace remaining on violation $vid for node $mac. Not adding violation.";
             violation_add_errors($msg);
             $logger->info($msg);
-            $pf::StatsD::statsd->end(called() . ".timing" , $start, 0.25 );
             return (-1);
+        } elsif ( $remaining_time > 0 && $data{'force'} eq $TRUE ) {
+            my $msg = "Force violation $vid for node $mac even if $remaining_time grace remaining";
+            $logger->info($msg);
         } else {
             my $msg = "grace expired on violation $vid for node $mac";
             $logger->info($msg);
@@ -497,7 +492,6 @@ sub violation_add {
         if($data{status} eq 'open') {
             pf::action::action_execute( $mac, $vid, $data{notes} );
         }
-        $pf::StatsD::statsd->end(called() . ".timing" , $start, 0.25 );
         return ($last_id);
     } else {
         my $msg = "unknown error adding violation $vid for $mac";
@@ -505,7 +499,6 @@ sub violation_add {
         $logger->error($msg);
     }
 
-    $pf::StatsD::statsd->end(called() . ".timing" , $start, 0.25 );
     return (0);
 }
 
@@ -552,6 +545,8 @@ sub info_for_violation_engine {
     my ($mac,$type,$tid) = @_;
     my $node_info = pf::node::node_view($mac);
 
+    my $cache = pf::CHI->new( namespace => 'fingerbank' );
+
     $type = lc($type);
 
     my $devices = [];
@@ -566,32 +561,47 @@ sub info_for_violation_engine {
         }
     }
     if(defined($device_id)){
-        my (undef,$device) = fingerbank::Model::Device->read($device_id,1);
-        $devices = $device->{parents_ids};
-        push @$devices, $device->{id};
-        @$devices = map {$_.""} @$devices;
+        $devices = $cache->compute("fingerbank::Model::Device_parents_$device_id", sub {
+            my (undef,$device) = fingerbank::Model::Device->read($device_id,1);
+            $devices = $device->{parents_ids};
+            push @$devices, $device->{id};
+            @$devices = map {$_.""} @$devices;
+            return $devices;
+        });
     }
 
-
-    my ($dhcp_fingerprint_result, $dhcp_fingerprint) = fingerbank::Model::DHCP_Fingerprint->find([{value => $node_info->{dhcp_fingerprint}}]);
-    my ($dhcp_vendor_result, $dhcp_vendor) = fingerbank::Model::DHCP_Vendor->find([{value => $node_info->{dhcp_vendor}}]);
-    my ($user_agent_result, $user_agent) = fingerbank::Model::User_Agent->find([{value => $node_info->{user_agent}}]);
-    my ($mac_vendor) = pf::fingerbank::mac_vendor_from_mac($mac);
+    my $attr_map = {
+        dhcp_fingerprint => "fingerbank::Model::DHCP_Fingerprint",
+        dhcp_vendor => "fingerbank::Model::DHCP_Vendor",
+        user_agent => "fingerbank::Model::User_Agent",
+    };
+    my $results = {};
+    foreach my $attr (keys %$attr_map){
+        my $model = $attr_map->{$attr};
+        my $query = {value => $node_info->{$attr}};
+        $results->{$attr} = $cache->compute_with_undef("$model\_id_".encode_json($query), sub {
+            my ($status, $result) = $model->find([$query]); 
+            return is_success($status) ? $result->id : undef;
+        });
+    }
+    my ($mac_vendor) = $cache->compute_with_undef("pf::fingerbank::mac_vendor_from_mac_$mac", sub { 
+        return pf::fingerbank::mac_vendor_from_mac($mac);
+    });
 
     my $info = {
       device_id => $devices,
-      dhcp_fingerprint_id => is_success($dhcp_fingerprint_result) ? $dhcp_fingerprint->id : undef,
-      dhcp_vendor_id => is_success($dhcp_vendor_result) ? $dhcp_vendor->id : undef,
+      dhcp_fingerprint_id => $results->{dhcp_fingerprint},
+      dhcp_vendor_id => $results->{dhcp_vendor},
       mac => $mac,
       mac_vendor_id => defined($mac_vendor) ? $mac_vendor->{id} : undef,
-      user_agent_id => is_success($user_agent_result) ? $user_agent->id : undef,
+      user_agent_id => $results->{user_agent},
     };
 
     my $trigger_info = $pf::factory::condition::violation::TRIGGER_TYPE_TO_CONDITION_TYPE{$type};
     if( $trigger_info->{type} ne 'includes' ){
         $info->{$trigger_info->{key}} = $tid;
     }
-
+    
     return $info;
 }
 
@@ -604,28 +614,25 @@ Returns 1 if at least one violation is added, 0 otherwise.
 =cut
 
 sub violation_trigger {
+    my $timer = pf::StatsD::Timer->new;
     my ( $mac, $tid, $type ) = @_;
     my $logger = get_logger();
-    my $start = Time::HiRes::gettimeofday();
     $logger->trace("Triggering violation $type $tid for mac $mac");
     return (0) if ( !$tid );
     $type = lc($type);
 
     if (whitelisted_mac($mac)) {
         $logger->info("violation not added, $mac is whitelisted! trigger ${type}::${tid}");
-        $pf::StatsD::statsd->end(called() . ".timing" , $start, 0.25 );
         return 0;
     }
 
     if (!valid_mac($mac)) {
         $logger->info("violation not added, MAC $mac is invalid! trigger ${type}::${tid}");
-        $pf::StatsD::statsd->end(called() . ".timing" , $start, 0.25 );
         return 0;
     }
 
     if (!trappable_mac($mac)) {
         $logger->info("violation not added, MAC $mac is not trappable! trigger ${type}::${tid}");
-        $pf::StatsD::statsd->end(called() . ".timing" , $start, 0.25 );
         return 0;
     }
 
@@ -709,7 +716,6 @@ sub violation_trigger {
         violation_add($mac, $vid, %data);
         $addedViolation = 1;
     }
-    $pf::StatsD::statsd->end(called() . ".timing" , $start, 0.25 );
     return $addedViolation;
 }
 
@@ -914,7 +920,7 @@ Minor parts of this file may have been contributed. See CREDITS.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2015 Inverse inc.
+Copyright (C) 2005-2016 Inverse inc.
 
 Copyright (C) 2005 Kevin Amorin
 
